function lokglobFehler_linear
  % Anzahl der Verfeinerungen
  nref = 6;

  % Rechte Seite, Anfangszeit, Endzeit, Anfangswert
  f = @(t,y) y;
  t0 = 0;
  T  = 1;
  y0 = 2;

  % Exakte Loesung
  exaktsol =@(t) y0*exp(t);

  % Alloziere Speicherplatz
  locFehler_quadraturRK   = zeros(1,nref);
  locFehler_klassischeRK  = zeros(1,nref);
  globFehler_quadraturRK  = zeros(1,nref);
  globFehler_klassischeRK = zeros(1,nref);

  % Array mit Schrittweiten
  h = 2.^(-[3:nref+2]);
  
  for ii = 1:nref
      % Lokaler Fehler nach einem Schritt / Einschritt-Fehler
      [tlocquadraturRK,ylocquadraturRK]   = quadraturRK(f,t0,h(ii),y0,1);
      [tlocklassischeRK,ylocklassischeRK] = klassischeRK(f,t0,h(ii),y0,1);

      y1exakt = exaktsol(h(ii));

      locFehler_quadraturRK(ii)  = abs(y1exakt - ylocquadraturRK(:,end));
      locFehler_klassischeRK(ii) = abs(y1exakt - ylocklassischeRK(:,end));

      % Globaler Fehler
      N = 2^(ii+2);
      [tglobquadraturRK,yglobquadraturRK]   = quadraturRK(f,t0,T,y0,N);
      [tglobklassischeRK,yglobklassischeRK] = klassischeRK(f,t0,T,y0,N);
      
      globFehler_quadraturRK(ii) = abs(exaktsol(T) - yglobquadraturRK(:,end));
      globFehler_klassischeRK(ii) = abs(exaktsol(T) - yglobklassischeRK(:,end));

  end

  % loglog plot von lokalem und globalem Fehler
  figure;
  loglog(h,globFehler_quadraturRK,'*-',h,locFehler_quadraturRK,'*-',...
         h,globFehler_klassischeRK,'*-',h,locFehler_klassischeRK,'*-');
  legend('RK Quadratur glob','RK Quadratur loc','klassiscche RK glob','klassiscche RK loc')

  % Konvergenzrate
  fit_locFehler_quadraturRK   = polyfit(log(h),log(locFehler_quadraturRK),1);
  fit_locFehler_klassischeRK  = polyfit(log(h),log(locFehler_klassischeRK),1);
  fit_globFehler_quadraturRK  = polyfit(log(h),log(globFehler_quadraturRK),1);
  fit_globFehler_klassischeRK = polyfit(log(h),log(globFehler_klassischeRK),1);
  fprintf([' RK Quadratur: Lokaler Fehler:  %1.2f\n RK Quadratur: Globaler Fehler: %1.2f\n'...
      ' klassiscche RK: Lokaler Fehler:  %1.2f\n klassiscche RK: Globaler Fehler: %1.2f\n'], ...
        fit_locFehler_quadraturRK(1),fit_globFehler_quadraturRK(1),fit_locFehler_klassischeRK(1),fit_globFehler_klassischeRK(1));
  grid on;

end
