function [t,y] = quadraturRK(f,t0,T,y0,N)

% function [t,y] = quadraturRK(f,t0,T,y0,N)
%
% Zweck: integriere die gewoehnliche Diff.-Gleichung erster Ordnung
%
%          dy/dt = f(t,y(t))
%
%        mit dem Verfahren basierend auf der Quadraturregel
%
%          \int_0^1 f(x) dx ~ Q[f] = (f(1/4) + f(3/4))/2
%
% Parameters: f    ... rechte Seite f(t,y(t)) der gew. Diff.-Gl.
%             t0,T ... Start- und End-Zeit
%             y0   ... Anfagswert
%             N    ... Anzahl Schritte
%
% Returns: t ... Zeiten
%          y ... approx. Loesung zu Zeiten t
%
% Notes: Keine.
%

% Berechne Zeitschritt
  h = (T - t0)/N;

% Speicher fuer Zeit & approx. Loesung
  t = zeros(1,N+1);
  y = zeros(length(y0),N+1);

% Setze Anfangswert
  t(1) = t0;
  y(:,1) = y0;

% Integriere
  for j=1:N
    t(j+1) = t0 + j*h;
    k1 = f(t(j),y(:,j));
    k2 = f(t(j) + 0.25*h,y(:,j) + 0.25*h*k1);
    k3 = f(t(j) + 0.75*h,y(:,j) + 0.75*h*k1);
    y(:,j+1) = y(:,j) + (h/2)*(k2 + k3);
  end

